import json
import logging

from flask import Flask, request

app = Flask(__name__)


def run(host, port):
    app.run(debug=True, host=host, port=port, use_reloader=False)


@app.route('/hello', methods=['get'])
def hello():
    data = request.get_json()
    logging.info(data)

    response = app.response_class(
        response=json.dumps({}),
        status=200,
        mimetype='application/json'
    )
    return response



import logging

from worker.server import server
from worker import utils
from apscheduler.schedulers.background import BackgroundScheduler

HOST = "0.0.0.0"
PORT = "8080"

HARBOR_SVC_FQDN = "harbor.harbor.svc.cluster.local."
HARBOR_SVC = "harbor.harbor.svc"


def serve():
    sched = BackgroundScheduler(daemon=True)
    sched.add_job(lambda: utils.set_host_from_kubernetes_dns(HARBOR_SVC, HARBOR_SVC_FQDN), 'interval', minutes=1)
    sched.start()
    logging.info("Starting host sync..")

    server.run(host=HOST, port=PORT)


import logging

import dns.resolver


def set_host_from_kubernetes_dns(host, host_fqdn):
    resolver = dns.resolver.Resolver()
    resolver.nameservers = ['10.96.0.10'] # 쿠버 IP는 고정
    answers = resolver.resolve(host_fqdn, "A")
    ip = answers[0].to_text()
    record = "{} {}\n".format(ip, host)

    path = '/etc/hosts'
    lines = open(path, 'r').readlines()

    found = False
    changed = False

    for i, v in enumerate(lines):
        if host in v:
            found = True
            if v.split(' ')[0] != ip:
                lines[i] = record
                changed = True
            break

    if changed or not found:
        if not found:
            lines.append(record)
            logging.info("New record : {}".format(host))
        out = open(path, 'w')
        out.writelines(lines)
        out.close()
        logging.info("Synced record : {}".format(host))
